==> coloredlogger-1.3.5.tar.gz: coloredlogger-1.3.5/setup.py <==
"""Setup module of Colored Logger.
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='coloredlogger',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='1.3.5',
    description='Colored Logger for Python',
    long_description=open(path.join(here, "README.rst")).read(),
    # The project's main homepage.
    url='https://github.com/fmakdemir/colored-logger',
    # Author details
    author='Fma',
    author_email='fmakdemir@gmail.com',
    # Choose your license
    license='MIT',
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: System :: Logging',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='coloredlogger logger log colored linux color colour coloured',
    py_modules=["coloredlogger"],
    install_requires=['colorama']
)

==> coloredlogger-1.3.12.tar.gz: coloredlogger-1.3.12/setup.py <==
"""Setup module of Colored Logger.
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='coloredlogger',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='1.3.12',
    description='Colored Logger for Python',
    long_description=str(open(path.join(here, "README.rst")).read()),
    # The project's main homepage.
    url='https://github.com/fmakdemir/colored-logger',
    # Author details
    author='Fma',
    author_email='fmakdemir@gmail.com',
    # Choose your license
    license='MIT',
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: System :: Logging',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='coloredlogger logger log colored linux color colour coloured',
    py_modules=["coloredlogger"],
    install_requires=['colorama']
)
